summaryrefslogtreecommitdiff
path: root/src/core/mount.c
diff options
context:
space:
mode:
authorMichal Koutný <mkoutny@suse.com>2016-04-25 13:25:00 +0200
committerMichal Koutný <mkoutny@suse.com>2016-04-25 13:25:00 +0200
commitd3bd0986bb7f3527620359aedf77253b16927ba1 (patch)
treea3278c3cb96ef4ae998c202526610bc229ee78a4 /src/core/mount.c
parent26919ac110c543291b1ad6fa6f22f56253de704d (diff)
Always create dependencies for loop device mounts
In case a file is on a networked filesystem, we may tag the fstab record with _netdev option, however, corrrect dependencies will be created for this mount.
Diffstat (limited to 'src/core/mount.c')
-rw-r--r--src/core/mount.c13
1 files changed, 11 insertions, 2 deletions
diff --git a/src/core/mount.c b/src/core/mount.c
index efb4a39eb4..6cfca1a4a9 100644
--- a/src/core/mount.c
+++ b/src/core/mount.c
@@ -86,6 +86,15 @@ static bool mount_is_network(const MountParameters *p) {
return mount_needs_network(p->options, p->fstype);
}
+static bool mount_is_loop(const MountParameters *p) {
+ assert(p);
+
+ if (fstab_test_option(p->options, "loop\0"))
+ return true;
+
+ return false;
+}
+
static bool mount_is_bind(const MountParameters *p) {
assert(p);
@@ -269,12 +278,12 @@ static int mount_add_mount_links(Mount *m) {
}
/* Adds in links to other mount points that might be needed
* for the source path (if this is a bind mount) to be
* available. */
pm = get_mount_parameters_fragment(m);
if (pm && pm->what &&
path_is_absolute(pm->what) &&
- (mount_is_bind(pm) || !mount_is_network(pm))) {
+ (mount_is_bind(pm) || mount_is_loop(pm) || !mount_is_network(pm))) {
r = unit_require_mounts_for(UNIT(m), pm->what);
if (r < 0)
@@ -269,12 +278,12 @@ static int mount_add_mount_links(Mount *m) {
}
/* Adds in links to other mount points that might be needed
- * for the source path (if this is a bind mount) to be
+ * for the source path (if this is a bind mount or a loop mount) to be
* available. */
pm = get_mount_parameters_fragment(m);